@@ -26,6 +26,7 @@ from typing import (
 import jax
 import jax.numpy as jnp
 import numpy as np
+from jax.scipy.special import logsumexp
 
 from pgmax.bp import infer
 from pgmax.fg import fg_utils, groups, nodes
@@ -117,7 +118,7 @@ class FactorGraph:
         """
         factor_group = groups.EnumerationFactorGroup(
             self._variable_group,
-            connected_variable_names=[variable_names],
+            variable_names_for_factors=[variable_names],
             factor_configs=factor_configs,
             log_potentials=log_potentials,
         )
@@ -736,7 +737,7 @@ class Evidence:
             name: The name of a variable group or a single variable.
                 If name is the name of a variable group, updates are derived by using the variable group to
                 flatten the data.
-                If name is the name of a variable, data should be of an array shape (variable_size,)
+                If name is the name of a variable, data should be of an array shape (num_states,)
                 If name is None, updates are derived by using self.fg_state.variable_group to flatten the data.
             data: Array containing the evidence updates.
         """
@@ -781,12 +782,16 @@ class BPArrays:
         return cls(**aux_data.unflatten(children))
 
 
-def BP(bp_state: BPState, num_iters: int) -> Tuple[Callable, Callable, Callable]:
+def BP(
+    bp_state: BPState, num_iters: int, temperature: float = 0.0
+) -> Tuple[Callable, Callable, Callable]:
     """Function for generating belief propagation functions.
 
     Args:
         bp_state: Belief propagation state.
         num_iters: Number of belief propagation iterations.
+        temperature: Temperature for loopy belief propagation.
+            1.0 corresponds to sum-product, 0.0 corresponds to max-product.
 
     Returns:
         Tuple containing\n
@@ -843,6 +848,7 @@ def BP(bp_state: BPState, num_iters: int) -> Tuple[Callable, Callable, Callable]
             ftov_msgs, wiring.edges_num_states, max_msg_size
         )
 
+        @jax.checkpoint
         def update(msgs: jnp.ndarray, _) -> Tuple[jnp.ndarray, None]:
             # Compute new variable to factor messages by message passing
             vtof_msgs = infer.pass_var_to_fac_messages(
@@ -856,6 +862,7 @@ def BP(bp_state: BPState, num_iters: int) -> Tuple[Callable, Callable, Callable]
                 wiring.factor_configs_edge_states,
                 log_potentials,
                 num_val_configs,
+                temperature,
             )
             # Use the results of message passing to perform damping and
             # update the factor to variable messages
@@ -930,3 +937,20 @@ def decode_map_states(beliefs: Any) -> Any:
         beliefs,
     )
     return map_states
+
+
+@jax.jit
+def get_marginals(beliefs: Any) -> Any:
+    """Function to get marginal probabilities given the calculated beliefs.
+
+    Args:
+        beliefs: An array or a PyTree container containing beliefs for different variables.
+
+    Returns:
+        An array or a PyTree container containing the marginal probabilities different variables.
+    """
+    marginals = jax.tree_util.tree_map(
+        lambda x: jnp.exp(x - logsumexp(x, axis=-1, keepdims=True)),
+        beliefs,
+    )
+    return marginals
